# tket-qsystem

![msrv][]

A TKET tool for preparing and validating `Hugr`s for compilation targeting
Quantinuum System  quantum computers.

## Usage

Install using `cargo`:

```bash
cargo install tket-qsystem
```

This will install the `tket-qsystem` binary.

## Recent Changes

See [CHANGELOG][] for a list of changes. The minimum supported rust
version will only change on major releases.

## Development

See [DEVELOPMENT.md][] for instructions on setting up the development environment.

## License

This project is licensed under Apache License, Version 2.0 ([LICENSE][] or <http://www.apache.org/licenses/LICENSE-2.0>).

  [msrv]: https://img.shields.io/crates/msrv/tket-qsystem
  [LICENSE]: https://github.com/CQCL/tket2/blob/main/LICENCE
  [CHANGELOG]: https://github.com/CQCL/tket2/blob/main/tket-qsystem/CHANGELOG.md
  [DEVELOPMENT.md]: https://github.com/CQCL/tket2/blob/main/DEVELOPMENT.md
